summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSean Whitton <spwhitton@spwhitton.name>2022-09-22 10:07:01 -0700
committerSean Whitton <spwhitton@spwhitton.name>2022-09-22 10:11:19 -0700
commit9d38a14f6d0e018a40124856b446809d958618d7 (patch)
tree4b6e211a0507e77a172b103d9c9b6cdadb272725
parentf7d6e749dbe2c6d9add5622b580018a9e0a87326 (diff)
downloaddotfiles-9d38a14f6d0e018a40124856b446809d958618d7.tar.gz
load git-commit.el immediately & mention git-commit-mode in comment
While git-rebase-mode has an entry in auto-mode-alist at Emacs startup, git-commit-mode will not be activated in COMMIT_EDITMSG buffers until and unless the library has been loaded.
-rw-r--r--.emacs.d/init.el8
1 files changed, 5 insertions, 3 deletions
diff --git a/.emacs.d/init.el b/.emacs.d/init.el
index f4deec06..fbc5eff9 100644
--- a/.emacs.d/init.el
+++ b/.emacs.d/init.el
@@ -3260,9 +3260,11 @@ mutt's review view, after exiting EDITOR."
;;;; VC
-;;; Want Magit installed for `git-rebase-mode' and these reflog commands.
-;;; Otherwise, I prefer how VC is more buffer-oriented, such as in eschewing
-;;; the (singular) Git staging area in favour of buffers in `diff-mode'.
+;;; Want Magit installed for `git-commit-mode', `git-rebase-mode' and these
+;;; reflog commands. Otherwise, I prefer how VC is more buffer-oriented, such
+;;; as in eschewing the (singular) Git staging area for `diff-mode' buffers.
+
+(require 'git-commit nil t)
(global-set-key "\C-cvr" #'magit-reflog-current)
(global-set-key "\C-cvH" #'magit-reflog-head)